@@ -332,6 +332,24 @@ Music = {
             return false;
         });
 
+        $("td.voteCount").live({
+            mouseenter: function() {
+                var element = $(this);
+                var tooltip = $(this).find('div.voteTooltip');
+                if (tooltip.length == 1) {
+                    tooltip.css('left', element.offset().left - $(window).scrollLeft() + 50);
+                    tooltip.css('top', element.offset().top - $(window).scrollTop() + 10);
+                    tooltip.show();
+                }
+            },
+            mouseleave: function() {
+                var tooltip = $(this).find('div.voteTooltip');
+                if (tooltip.length == 1) {
+                    tooltip.hide();
+                }
+            }
+        });
+
         $.ajaxSetup({
             type: "GET",
             cache: false,
@@ -522,6 +540,13 @@ Music = {
                 break;
             case "history":
                 html+= "<tr class=\"history\">";
+                html+= "<th class=\"options\">&#160;</th>";
+                html+= "<th class=\"favourite_title sort_title" + Music.getOrderClass("title", data) + "\">" + gettext("Title") + "</th>";
+                html+= "<th class=\"favourite_artist sort_artist" + Music.getOrderClass("artist", data) + "\">" + gettext("Artist") + "</th>";
+                html+= "<th class=\"favourite_album sort_album" + Music.getOrderClass("album", data) + "\">" + gettext("Album") + "</th>";
+                html+= "<th class=\"favourite_genre sort_genre" + Music.getOrderClass("votes", data) + "\">" + gettext("Votes") + "</th>";
+                html+= "<th class=\"favourite_added sort_created" + Music.getOrderClass("created", data) + "\">" + gettext("Date added") + "</th>";
+                break;
             case "history/my":
                 html+= "<tr class=\"history_my\">";
                 html+= "<th class=\"options\">&#160;</th>";
@@ -619,7 +644,23 @@ Music = {
                         html+= "<td>&#160;</td>";
                     }
 
-                    html+= "<td class=\"voteCount\">" + item.votes + "</td>";
+                    html+= "<td class=\"voteCount\">";
+                    if (item.votes > 0) {
+                        if (item.users.length == item.votes) {
+                            html+= "<div class=\"voteTooltip\"><ul>";
+                            for (var key in item.users) {
+                                var user = item.users[key];
+                                html+= "<li>" + user.name + "</li>"
+                            }
+                            html+= "</ul></div>";
+                        }
+                        html+= item.votes;
+                    }
+                    else {
+                        html+= gettext("Autoplay");
+                    }
+                    html+= "</td>";
+
                     html+= "<td>" + item.created + "</td>";
                     break;
                 case "history":
@@ -664,7 +705,23 @@ Music = {
                         html+= "<td>&#160;</td>";
                     }
 
-                    html+= "<td>" + ((item.votes > 0) ? item.votes : gettext("Autoplay")) + "</td>";
+                    html+= "<td class=\"voteCount\">";
+                    if (item.votes > 0) {
+                        if (item.users.length == item.votes) {
+                            html+= "<div class=\"voteTooltip\"><ul>";
+                            for (var key in item.users) {
+                                var user = item.users[key];
+                                html+= "<li>" + user.name + "</li>"
+                            }
+                            html+= "</ul></div>";
+                        }
+                        html+= item.votes;
+                    }
+                    else {
+                        html+= gettext("Autoplay");
+                    }
+                    html+= "</td>";
+
                     html+= "<td>" + item.created + "</td>";
                     break;
                 case "favourites":
