@@ -5,7 +5,7 @@ ADMINS = (
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
-SECRET_KEY = "yourSecretKey"
+SECRET_KEY = "flskf;lsdkflkaw409itc[43umtm9c43u9u*(NYB*(Y89cyptn894"
 
 AUTHENTICATION_BACKENDS = (
     "django.contrib.auth.backends.ModelBackend",
@@ -24,5 +24,3 @@ GITHUB_API_SECRET = "3a8b5f1e09cb0878999fa248bfe3e6a7c4a73539"
 
 FACEBOOK_APP_ID = "299877236703542"
 FACEBOOK_API_SECRET = "9a581e96f686f4ca5b57b378b90d395d"
-
-
